"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.stripeSignatureValidationMiddleware = stripeSignatureValidationMiddleware;
exports.stripeWebhooksService = stripeWebhooksService;
var _bodyParser = _interopRequireDefault(require("body-parser"));
var _debug = _interopRequireDefault(require("debug"));
var _service = _interopRequireDefault(require("./service"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const debug = (0, _debug.default)('feathers-stripe-webhooks:main');
function stripeWebhooksService(handlers) {
  debug('Creating feathers-stripe-webhooks service');
  return (0, _service.default)(handlers);
}
function stripeSignatureValidationMiddleware(stripe, route, endpointSecret) {
  return function () {
    const app = this;
    const bodyParserRaw = _bodyParser.default.raw({
      type: '*/*'
    });
    app.post(route, bodyParserRaw, (req, res, next) => {
      const signature = req.headers['stripe-signature'];
      if (!signature) {
        res.status(400).end();
        return;
      }
      try {
        stripe.webhooks.constructEvent(req.body, signature, endpointSecret);
        req.body = JSON.parse(req.body.toString('utf8'));
      } catch (err) {
        res.status(400).end();
        return;
      }
      next();
    });
  };
}